@@ -1,6 +1,6 @@
 /* Channel support
  *
- * (C) 2008-2022 Anope Team
+ * (C) 2008-2023 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -289,6 +289,11 @@ class CoreExport Channel : public Base, public Extensible
 	 */
 	bool CheckKick(User *user);
 
+	/** Find which bot should send mode/topic/etc changes for this channel
+	 * @return The bot
+	 */
+	BotInfo *WhoSends() const;
+
 	/** Finds a channel
 	 * @param name The channel to find
 	 * @return The channel, if found
