@@ -1,6 +1,6 @@
 /* NickServ core functions
  *
- * (C) 2003-2022 Anope Team
+ * (C) 2003-2023 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -83,7 +83,7 @@ class CommandNSConfirm : public Command
 				source.Reply(_("Invalid passcode."));
 		}
 		else
-			source.Reply(_("Invalid passcode."));
+			source.Reply(NICK_IDENTIFY_REQUIRED);
 
 		return;
 	}
