@@ -1,6 +1,6 @@
 /* inspircd 1.2 functions
  *
- * (C) 2003-2022 Anope Team
+ * (C) 2003-2023 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -144,7 +144,7 @@ class InspIRCd12Proto : public IRCDProto
 	{
 		if (Servers::Capab.count("SVSTOPIC"))
 		{
-			UplinkSocket::Message(c->ci->WhoSends()) << "SVSTOPIC " << c->name << " " << c->topic_ts << " " << c->topic_setter << " :" << c->topic;
+			UplinkSocket::Message(c->WhoSends()) << "SVSTOPIC " << c->name << " " << c->topic_ts << " " << c->topic_setter << " :" << c->topic;
 		}
 		else
 		{
@@ -246,8 +246,16 @@ class InspIRCd12Proto : public IRCDProto
 	{
 		Anope::string modes = "+" + u->GetModes();
 		UplinkSocket::Message(Me) << "UID " << u->GetUID() << " " << u->timestamp << " " << u->nick << " " << u->host << " " << u->host << " " << u->GetIdent() << " 0.0.0.0 " << u->timestamp << " " << modes << " :" << u->realname;
+
 		if (modes.find('o') != Anope::string::npos)
+		{
+			// Mark as introduced so we can send an oper type.
+			BotInfo *bi = BotInfo::Find(u->nick, true);
+			if (bi)
+				bi->introduced = true;
+
 			UplinkSocket::Message(u) << "OPERTYPE :service";
+		}
 	}
 
 	/* SERVER services-dev.chatspike.net password 0 :Description here */
