@@ -1,7 +1,7 @@
 /* Mode support
  *
  * (C) 2008-2011 Adam <Adam@anope.org>
- * (C) 2008-2022 Anope Team <team@anope.org>
+ * (C) 2008-2023 Anope Team <team@anope.org>
  *
  * Please read COPYING and README for further details.
  */
@@ -617,7 +617,7 @@ void ModeManager::StackerAdd(BotInfo *bi, Channel *c, ChannelMode *cm, bool Set,
 	if (bi)
 		s->bi = bi;
 	else
-		s->bi = c->ci->WhoSends();
+		s->bi = c->WhoSends();
 
 	if (!modePipe)
 		modePipe = new ModePipe();
